"""
DIALS Regression Data Manager
https://github.com/dials/data
"""

__all__ = []
__author__ = """Markus Gerstel"""
__email__ = "dials-support@lists.sourceforge.net"
__version__ = "2.1.32"
__commit__ = "2a1fdea9aff5889ceef866b5b3c635ec194cee6d"
__version_tuple__ = tuple(int(x) for x in __version__.split("."))
